@@ -373,7 +373,7 @@ def _wikipron_uk(lexicon: citylex_pb2.Lexicon) -> None:
     counter = 0
     url = (
         "https://raw.githubusercontent.com/kylebgorman/"
-        "wikipron/master/data/tsv/eng_uk_phonemic_filtered.tsv"
+        "wikipron/master/data/scrape/tsv/eng_latn_us_broad_filtered.tsv"
     )
     for line in _request_url_resource(url):
         (wordform, pron, *_) = line.rstrip().split("\t")
@@ -392,7 +392,7 @@ def _wikipron_us(lexicon: citylex_pb2.Lexicon) -> None:
     counter = 0
     url = (
         "https://raw.githubusercontent.com/kylebgorman/"
-        "wikipron/master/data/tsv/eng_us_phonemic_filtered.tsv"
+        "wikipron/master/data/scrape/tsv/eng_latn_us_broad_filtered.tsv"
     )
     for line in _request_url_resource(url):
         (wordform, pron, *_) = line.rstrip().split("\t")
@@ -421,7 +421,7 @@ def main() -> None:
     parser.add_argument(
         "--all-free",
         action="store_true",
-        help="extracts all free data sources"
+        help="extract all free data sources"
     )
     parser.add_argument(
         "--celex",
@@ -466,7 +466,7 @@ def main() -> None:
     parser.add_argument(
         "--unimorph",
         action="store_true",
-        help="extract UniMorph data (C BY-SA 2.0): "
+        help="extract UniMorph data (CC BY-SA 2.0): "
         "http://creativecommons.org/licenses/by-sa/2.0/",
     )
     parser.add_argument(
